Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(240)

Unified Diff: chrome/test/automation/automation_messages_internal.h

Issue 164446: linux: More automation porting. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: automation ipc messages hack fix Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/views/find_bar_win_interactive_uitest.cc ('k') | chrome/test/automation/window_proxy.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/automation/automation_messages_internal.h
===================================================================
--- chrome/test/automation/automation_messages_internal.h (revision 23277)
+++ chrome/test/automation/automation_messages_internal.h (working copy)
@@ -12,6 +12,7 @@
#include <vector>
#include "base/basictypes.h"
+#include "base/gfx/point.h"
#include "base/gfx/rect.h"
#include "base/string16.h"
#include "chrome/common/navigation_types.h"
@@ -389,16 +390,20 @@
int /* AutocompleteEdit handle */)
#if defined(OS_WIN)
- // TODO(port): Port this message.
+ // TODO(estade): This message is defined later on for Mac and Linux. This is
+ // to avoid adding a new IPC in the middle for those platforms (see comment
+ // at top). The message is exactly the same, so they should be remerged when
+ // all messages in this file have been made cross-platform (at which point we
+ // will need to check in new reference builds).
//
// This message requests that a mouse click be performed in window coordinate
// space.
// Request:
// int - the handle of the window that's the context for this click
// POINT - the point to click
// int - the flags which identify the mouse button(s) for the click, as
// defined in chrome/views/event.h
- IPC_MESSAGE_ROUTED3(AutomationMsg_WindowClick, int, POINT, int)
+ IPC_MESSAGE_ROUTED3(AutomationMsg_WindowClick, int, gfx::Point, int)
#endif // defined(OS_WIN)
// This message requests that a key press be performed.
@@ -988,4 +993,8 @@
IPC_SYNC_MESSAGE_ROUTED0_1(AutomationMsg_GetFilteredInetHitCount,
int /* hit_count */)
+#if defined(OS_LINUX) || defined(OS_MACOSX)
tony 2009/08/13 21:15:20 Maybe add a short comment here to look above?
+ IPC_MESSAGE_ROUTED3(AutomationMsg_WindowClick, int, gfx::Point, int)
+#endif
+
IPC_END_MESSAGES(Automation)
« no previous file with comments | « chrome/browser/views/find_bar_win_interactive_uitest.cc ('k') | chrome/test/automation/window_proxy.h » ('j') | no next file with comments »
@@ -389,16 +390,20 @@
// Request:
// int - the handle of the window that's the context for this click
- // POINT - the point to click
+ // gfx::Point - the point to click
// int - the flags which identify the mouse button(s) for the click, as
// defined in chrome/views/event.h

Powered by Google App Engine
This is Rietveld 408576698